=======
Pyntual
=======


.. image:: https://img.shields.io/pypi/v/pyntual.svg
        :target: https://pypi.python.org/pypi/pyntual

.. image:: https://img.shields.io/travis/com/vlizanae/pyntual.svg
        :target: https://travis-ci.com/vlizanae/pyntual

.. image:: https://readthedocs.org/projects/pyntual/badge/?version=latest
        :target: https://pyntual.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Fintual API Python client.


* Free software: MIT license
* Documentation: https://pyntual.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created from the `audreyr/cookiecutter-pypackage`_ project template using Cookiecutter_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
